pub struct Completion<'a, T, E: RingOp<T>> { /* private fields */ }Expand description
Context object passed to RingOp::complete.
Implementations
Sourceimpl<T, E: RingOp<T>> Completion<'_, T, E>
impl<T, E: RingOp<T>> Completion<'_, T, E>
Sourcepub fn context_mut(&mut self) -> &mut T
pub fn context_mut(&mut self) -> &mut T
Returns a mutable reference to the context value stored in a Ring.
Sourcepub fn push(&mut self, op: E)
pub fn push(&mut self, op: E)
Pushes an operation to the submission queue.
This can be used to push new operations from within RingOp::complete.
See also Ring::push.